.. include:: ../README.rst

This documentation
==================

.. toctree::
   :maxdepth: 2
  
   overview
   todo
   copying

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
